@@ -31,7 +31,10 @@ case_match <- function(.x, ..., .default = NA, .ptype = NULL) {
 #' @export
 #' @keywords internal
 #' @inherit case_match
-case_match. <- case_match
+case_match. <- function(.x, ..., .default = NA, .ptype = NULL) {
+  deprecate_dot_fun()
+  case_match(.x, ..., .default = NA, .ptype = NULL)
+}
 
 prep_case_match_dot <- function(dot, .x) {
   lhs <- f_lhs(dot)
