@@ -15,7 +15,10 @@ pmap <- function(.l, .f, ...) {
 #' @export
 #' @keywords internal
 #' @inherit map
-pmap. <- pmap
+pmap. <- function(.l, .f, ...) {
+  deprecate_dot_fun()
+  pmap(.l, .f, ...)
+}
 
 #' @export
 #' @rdname map
@@ -26,7 +29,10 @@ pmap_lgl <- function(.l, .f, ...) {
 #' @export
 #' @keywords internal
 #' @inherit map
-pmap_lgl. <- pmap_lgl
+pmap_lgl. <- function(.l, .f, ...) {
+  deprecate_dot_fun()
+  pmap_lgl(.l, .f, ...)
+}
 
 #' @export
 #' @rdname map
@@ -37,7 +43,10 @@ pmap_int <- function(.l, .f, ...) {
 #' @export
 #' @keywords internal
 #' @inherit map
-pmap_int. <- pmap_int
+pmap_int. <- function(.l, .f, ...) {
+  deprecate_dot_fun()
+  pmap_int(.l, .f, ...)
+}
 
 #' @export
 #' @rdname map
@@ -48,7 +57,10 @@ pmap_dbl <- function(.l, .f, ...) {
 #' @export
 #' @keywords internal
 #' @inherit map
-pmap_dbl. <- pmap_dbl
+pmap_dbl. <- function(.l, .f, ...) {
+  deprecate_dot_fun()
+  pmap_dbl(.l, .f, ...)
+}
 
 #' @export
 #' @rdname map
@@ -59,7 +71,10 @@ pmap_chr <- function(.l, .f, ...) {
 #' @export
 #' @keywords internal
 #' @inherit map
-pmap_chr. <- pmap_chr
+pmap_chr. <- function(.l, .f, ...) {
+  deprecate_dot_fun()
+  pmap_chr(.l, .f, ...)
+}
 
 #' @export
 #' @rdname map
@@ -71,7 +86,10 @@ pmap_dfc <- function(.l, .f, ...) {
 #' @export
 #' @keywords internal
 #' @inherit map
-pmap_dfc. <- pmap_dfc
+pmap_dfc. <- function(.l, .f, ...) {
+  deprecate_dot_fun()
+  pmap_dfc(.l, .f, ...)
+}
 
 #' @export
 #' @rdname map
@@ -83,7 +101,10 @@ pmap_dfr <- function(.l, .f, ..., .id = NULL) {
 #' @export
 #' @keywords internal
 #' @inherit map
-pmap_dfr. <- pmap_dfr
+pmap_dfr. <- function(.l, .f, ..., .id = NULL) {
+  deprecate_dot_fun()
+  pmap_dfr(.l, .f, ..., .id = .id)
+}
 
 #' @export
 #' @rdname map
@@ -92,7 +113,10 @@ pmap_df <- pmap_dfr
 #' @export
 #' @keywords internal
 #' @inherit map
-pmap_df. <- pmap_df
+pmap_df. <- function(.l, .f, ..., .id = NULL) {
+  deprecate_dot_fun()
+  pmap_df(.l, .f, ..., .id = .id)
+}
 
 #' @export
 #' @rdname map
