@@ -35,18 +35,8 @@
 #' df %>%
 #'   unite()
 unite <- function(.df, col = ".united", ..., sep = "_", remove = TRUE, na.rm = FALSE) {
-  unite.(.df, {{ col }}, ..., sep = sep, remove = remove, na.rm = na.rm)
-}
+  .df <- .df_as_tidytable(.df)
 
-#' @export
-#' @keywords internal
-#' @inherit unite
-unite. <- function(.df, col = ".united", ..., sep = "_", remove = TRUE, na.rm = FALSE) {
-  UseMethod("unite.")
-}
-
-#' @export
-unite..tidytable <- function(.df, col = ".united", ..., sep = "_", remove = TRUE, na.rm = FALSE) {
   col <- as_name(enquo(col))
 
   dots <- enquos(...)
@@ -80,8 +70,10 @@ unite..tidytable <- function(.df, col = ".united", ..., sep = "_", remove = TRUE
 }
 
 #' @export
-unite..data.frame <- function(.df, col = ".united", ..., sep = "_", remove = TRUE, na.rm = FALSE) {
-  .df <- as_tidytable(.df)
+#' @keywords internal
+#' @inherit unite
+unite. <- function(.df, col = ".united", ..., sep = "_", remove = TRUE, na.rm = FALSE) {
+  deprecate_dot_fun()
   unite(.df, {{ col }}, ..., sep = sep, remove = remove, na.rm = na.rm)
 }
 
