@@ -16,5 +16,5 @@ test_that("na.rm works", {
 
 test_that("n_distinct. works", {
   x <- c("a", "a", "b")
-  expect_equal(n_distinct.(x), 2)
+  expect_equal(suppressWarnings(n_distinct.(x)), 2)
 })
